==> codeguruprofiler-1.60.0-sources.jar: software/amazon/awscdk/services/codeguruprofiler/CfnProfilingGroupProps.java <==
package software.amazon.awscdk.services.codeguruprofiler;

/**
 * Properties for defining a `AWS::CodeGuruProfiler::ProfilingGroup`.
 * <p>
 * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-codeguruprofiler-profilinggroup.html
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.9.0 (build 5c646d5)", date = "2020-08-19T23:25:02.871Z")
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.services.codeguruprofiler.$Module.class, fqn = "@aws-cdk/aws-codeguruprofiler.CfnProfilingGroupProps")
@software.amazon.jsii.Jsii.Proxy(CfnProfilingGroupProps.Jsii$Proxy.class)
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
public interface CfnProfilingGroupProps extends software.amazon.jsii.JsiiSerializable {

    /**
     * `AWS::CodeGuruProfiler::ProfilingGroup.ProfilingGroupName`.
     * <p>
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-codeguruprofiler-profilinggroup.html#cfn-codeguruprofiler-profilinggroup-profilinggroupname
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @org.jetbrains.annotations.NotNull java.lang.String getProfilingGroupName();

    /**
     * `AWS::CodeGuruProfiler::ProfilingGroup.AgentPermissions`.
     * <p>
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-codeguruprofiler-profilinggroup.html#cfn-codeguruprofiler-profilinggroup-agentpermissions
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    default @org.jetbrains.annotations.Nullable java.lang.Object getAgentPermissions() {
        return null;
    }

    /**
     * `AWS::CodeGuruProfiler::ProfilingGroup.AnomalyDetectionNotificationConfiguration`.
     * <p>
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-codeguruprofiler-profilinggroup.html#cfn-codeguruprofiler-profilinggroup-anomalydetectionnotificationconfiguration
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    default @org.jetbrains.annotations.Nullable java.lang.Object getAnomalyDetectionNotificationConfiguration() {
        return null;
    }

    /**
     * `AWS::CodeGuruProfiler::ProfilingGroup.ComputePlatform`.
     * <p>
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-codeguruprofiler-profilinggroup.html#cfn-codeguruprofiler-profilinggroup-computeplatform
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    default @org.jetbrains.annotations.Nullable java.lang.String getComputePlatform() {
        return null;
    }

    /**
     * `AWS::CodeGuruProfiler::ProfilingGroup.Tags`.
     * <p>
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-codeguruprofiler-profilinggroup.html#cfn-codeguruprofiler-profilinggroup-tags
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    default @org.jetbrains.annotations.Nullable java.util.List<software.amazon.awscdk.core.CfnTag> getTags() {
        return null;
    }

    /**
     * @return a {@link Builder} of {@link CfnProfilingGroupProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    static Builder builder() {
        return new Builder();
    }
    /**
     * A builder for {@link CfnProfilingGroupProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static final class Builder implements software.amazon.jsii.Builder<CfnProfilingGroupProps> {
        private java.lang.String profilingGroupName;
        private java.lang.Object agentPermissions;
        private java.lang.Object anomalyDetectionNotificationConfiguration;
        private java.lang.String computePlatform;
        private java.util.List<software.amazon.awscdk.core.CfnTag> tags;

        /**
         * Sets the value of {@link CfnProfilingGroupProps#getProfilingGroupName}
         * @param profilingGroupName `AWS::CodeGuruProfiler::ProfilingGroup.ProfilingGroupName`. This parameter is required.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder profilingGroupName(java.lang.String profilingGroupName) {
            this.profilingGroupName = profilingGroupName;
            return this;
        }

        /**
         * Sets the value of {@link CfnProfilingGroupProps#getAgentPermissions}
         * @param agentPermissions `AWS::CodeGuruProfiler::ProfilingGroup.AgentPermissions`.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder agentPermissions(java.lang.Object agentPermissions) {
            this.agentPermissions = agentPermissions;
            return this;
        }

        /**
         * Sets the value of {@link CfnProfilingGroupProps#getAnomalyDetectionNotificationConfiguration}
         * @param anomalyDetectionNotificationConfiguration `AWS::CodeGuruProfiler::ProfilingGroup.AnomalyDetectionNotificationConfiguration`.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder anomalyDetectionNotificationConfiguration(software.amazon.awscdk.core.IResolvable anomalyDetectionNotificationConfiguration) {
            this.anomalyDetectionNotificationConfiguration = anomalyDetectionNotificationConfiguration;
            return this;
        }

        /**
         * Sets the value of {@link CfnProfilingGroupProps#getAnomalyDetectionNotificationConfiguration}
         * @param anomalyDetectionNotificationConfiguration `AWS::CodeGuruProfiler::ProfilingGroup.AnomalyDetectionNotificationConfiguration`.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder anomalyDetectionNotificationConfiguration(java.util.List<java.lang.Object> anomalyDetectionNotificationConfiguration) {
            this.anomalyDetectionNotificationConfiguration = anomalyDetectionNotificationConfiguration;
            return this;
        }

        /**
         * Sets the value of {@link CfnProfilingGroupProps#getComputePlatform}
         * @param computePlatform `AWS::CodeGuruProfiler::ProfilingGroup.ComputePlatform`.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder computePlatform(java.lang.String computePlatform) {
            this.computePlatform = computePlatform;
            return this;
        }

        /**
         * Sets the value of {@link CfnProfilingGroupProps#getTags}
         * @param tags `AWS::CodeGuruProfiler::ProfilingGroup.Tags`.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder tags(java.util.List<software.amazon.awscdk.core.CfnTag> tags) {
            this.tags = tags;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link CfnProfilingGroupProps}
         * @throws NullPointerException if any required attribute was not provided
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        @Override
        public CfnProfilingGroupProps build() {
            return new Jsii$Proxy(profilingGroupName, agentPermissions, anomalyDetectionNotificationConfiguration, computePlatform, tags);
        }
    }

    /**
     * An implementation for {@link CfnProfilingGroupProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements CfnProfilingGroupProps {
        private final java.lang.String profilingGroupName;
        private final java.lang.Object agentPermissions;
        private final java.lang.Object anomalyDetectionNotificationConfiguration;
        private final java.lang.String computePlatform;
        private final java.util.List<software.amazon.awscdk.core.CfnTag> tags;

        /**
         * Constructor that initializes the object based on values retrieved from the JsiiObject.
         * @param objRef Reference to the JSII managed object.
         */
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(objRef);
            this.profilingGroupName = this.jsiiGet("profilingGroupName", java.lang.String.class);
            this.agentPermissions = this.jsiiGet("agentPermissions", java.lang.Object.class);
            this.anomalyDetectionNotificationConfiguration = this.jsiiGet("anomalyDetectionNotificationConfiguration", java.lang.Object.class);
            this.computePlatform = this.jsiiGet("computePlatform", java.lang.String.class);
            this.tags = this.jsiiGet("tags", software.amazon.jsii.NativeType.listOf(software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.core.CfnTag.class)));
        }

        /**
         * Constructor that initializes the object based on literal property values passed by the {@link Builder}.
         */
        private Jsii$Proxy(final java.lang.String profilingGroupName, final java.lang.Object agentPermissions, final java.lang.Object anomalyDetectionNotificationConfiguration, final java.lang.String computePlatform, final java.util.List<software.amazon.awscdk.core.CfnTag> tags) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.profilingGroupName = java.util.Objects.requireNonNull(profilingGroupName, "profilingGroupName is required");
            this.agentPermissions = agentPermissions;
            this.anomalyDetectionNotificationConfiguration = anomalyDetectionNotificationConfiguration;
            this.computePlatform = computePlatform;
            this.tags = tags;
        }

        @Override
        public java.lang.String getProfilingGroupName() {
            return this.profilingGroupName;
        }

        @Override
        public java.lang.Object getAgentPermissions() {
            return this.agentPermissions;
        }

        @Override
        public java.lang.Object getAnomalyDetectionNotificationConfiguration() {
            return this.anomalyDetectionNotificationConfiguration;
        }

        @Override
        public java.lang.String getComputePlatform() {
            return this.computePlatform;
        }

        @Override
        public java.util.List<software.amazon.awscdk.core.CfnTag> getTags() {
            return this.tags;
        }

        @Override
        public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
            final com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
            final com.fasterxml.jackson.databind.node.ObjectNode data = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();

            data.set("profilingGroupName", om.valueToTree(this.getProfilingGroupName()));
            if (this.getAgentPermissions() != null) {
                data.set("agentPermissions", om.valueToTree(this.getAgentPermissions()));
            }
            if (this.getAnomalyDetectionNotificationConfiguration() != null) {
                data.set("anomalyDetectionNotificationConfiguration", om.valueToTree(this.getAnomalyDetectionNotificationConfiguration()));
            }
            if (this.getComputePlatform() != null) {
                data.set("computePlatform", om.valueToTree(this.getComputePlatform()));
            }
            if (this.getTags() != null) {
                data.set("tags", om.valueToTree(this.getTags()));
            }

            final com.fasterxml.jackson.databind.node.ObjectNode struct = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            struct.set("fqn", om.valueToTree("@aws-cdk/aws-codeguruprofiler.CfnProfilingGroupProps"));
            struct.set("data", data);

            final com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            obj.set("$jsii.struct", struct);

            return obj;
        }

        @Override
        public boolean equals(Object o) {
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;

            CfnProfilingGroupProps.Jsii$Proxy that = (CfnProfilingGroupProps.Jsii$Proxy) o;

            if (!profilingGroupName.equals(that.profilingGroupName)) return false;
            if (this.agentPermissions != null ? !this.agentPermissions.equals(that.agentPermissions) : that.agentPermissions != null) return false;
            if (this.anomalyDetectionNotificationConfiguration != null ? !this.anomalyDetectionNotificationConfiguration.equals(that.anomalyDetectionNotificationConfiguration) : that.anomalyDetectionNotificationConfiguration != null) return false;
            if (this.computePlatform != null ? !this.computePlatform.equals(that.computePlatform) : that.computePlatform != null) return false;
            return this.tags != null ? this.tags.equals(that.tags) : that.tags == null;
        }

        @Override
        public int hashCode() {
            int result = this.profilingGroupName.hashCode();
            result = 31 * result + (this.agentPermissions != null ? this.agentPermissions.hashCode() : 0);
            result = 31 * result + (this.anomalyDetectionNotificationConfiguration != null ? this.anomalyDetectionNotificationConfiguration.hashCode() : 0);
            result = 31 * result + (this.computePlatform != null ? this.computePlatform.hashCode() : 0);
            result = 31 * result + (this.tags != null ? this.tags.hashCode() : 0);
            return result;
        }
    }
}

==> codeguruprofiler-1.67.0-sources.jar: software/amazon/awscdk/services/codeguruprofiler/CfnProfilingGroupProps.java <==
package software.amazon.awscdk.services.codeguruprofiler;

/**
 * Properties for defining a `AWS::CodeGuruProfiler::ProfilingGroup`.
 * <p>
 * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-codeguruprofiler-profilinggroup.html
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.13.0 (build 385c325)", date = "2020-10-07T19:57:27.328Z")
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.services.codeguruprofiler.$Module.class, fqn = "@aws-cdk/aws-codeguruprofiler.CfnProfilingGroupProps")
@software.amazon.jsii.Jsii.Proxy(CfnProfilingGroupProps.Jsii$Proxy.class)
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
public interface CfnProfilingGroupProps extends software.amazon.jsii.JsiiSerializable {

    /**
     * `AWS::CodeGuruProfiler::ProfilingGroup.ProfilingGroupName`.
     * <p>
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-codeguruprofiler-profilinggroup.html#cfn-codeguruprofiler-profilinggroup-profilinggroupname
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @org.jetbrains.annotations.NotNull java.lang.String getProfilingGroupName();

    /**
     * `AWS::CodeGuruProfiler::ProfilingGroup.AgentPermissions`.
     * <p>
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-codeguruprofiler-profilinggroup.html#cfn-codeguruprofiler-profilinggroup-agentpermissions
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    default @org.jetbrains.annotations.Nullable java.lang.Object getAgentPermissions() {
        return null;
    }

    /**
     * `AWS::CodeGuruProfiler::ProfilingGroup.AnomalyDetectionNotificationConfiguration`.
     * <p>
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-codeguruprofiler-profilinggroup.html#cfn-codeguruprofiler-profilinggroup-anomalydetectionnotificationconfiguration
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    default @org.jetbrains.annotations.Nullable java.lang.Object getAnomalyDetectionNotificationConfiguration() {
        return null;
    }

    /**
     * `AWS::CodeGuruProfiler::ProfilingGroup.ComputePlatform`.
     * <p>
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-codeguruprofiler-profilinggroup.html#cfn-codeguruprofiler-profilinggroup-computeplatform
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    default @org.jetbrains.annotations.Nullable java.lang.String getComputePlatform() {
        return null;
    }

    /**
     * `AWS::CodeGuruProfiler::ProfilingGroup.Tags`.
     * <p>
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-codeguruprofiler-profilinggroup.html#cfn-codeguruprofiler-profilinggroup-tags
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    default @org.jetbrains.annotations.Nullable java.util.List<software.amazon.awscdk.core.CfnTag> getTags() {
        return null;
    }

    /**
     * @return a {@link Builder} of {@link CfnProfilingGroupProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    static Builder builder() {
        return new Builder();
    }
    /**
     * A builder for {@link CfnProfilingGroupProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static final class Builder implements software.amazon.jsii.Builder<CfnProfilingGroupProps> {
        private java.lang.String profilingGroupName;
        private java.lang.Object agentPermissions;
        private java.lang.Object anomalyDetectionNotificationConfiguration;
        private java.lang.String computePlatform;
        private java.util.List<software.amazon.awscdk.core.CfnTag> tags;

        /**
         * Sets the value of {@link CfnProfilingGroupProps#getProfilingGroupName}
         * @param profilingGroupName `AWS::CodeGuruProfiler::ProfilingGroup.ProfilingGroupName`. This parameter is required.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder profilingGroupName(java.lang.String profilingGroupName) {
            this.profilingGroupName = profilingGroupName;
            return this;
        }

        /**
         * Sets the value of {@link CfnProfilingGroupProps#getAgentPermissions}
         * @param agentPermissions `AWS::CodeGuruProfiler::ProfilingGroup.AgentPermissions`.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder agentPermissions(java.lang.Object agentPermissions) {
            this.agentPermissions = agentPermissions;
            return this;
        }

        /**
         * Sets the value of {@link CfnProfilingGroupProps#getAnomalyDetectionNotificationConfiguration}
         * @param anomalyDetectionNotificationConfiguration `AWS::CodeGuruProfiler::ProfilingGroup.AnomalyDetectionNotificationConfiguration`.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder anomalyDetectionNotificationConfiguration(software.amazon.awscdk.core.IResolvable anomalyDetectionNotificationConfiguration) {
            this.anomalyDetectionNotificationConfiguration = anomalyDetectionNotificationConfiguration;
            return this;
        }

        /**
         * Sets the value of {@link CfnProfilingGroupProps#getAnomalyDetectionNotificationConfiguration}
         * @param anomalyDetectionNotificationConfiguration `AWS::CodeGuruProfiler::ProfilingGroup.AnomalyDetectionNotificationConfiguration`.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder anomalyDetectionNotificationConfiguration(java.util.List<? extends java.lang.Object> anomalyDetectionNotificationConfiguration) {
            this.anomalyDetectionNotificationConfiguration = anomalyDetectionNotificationConfiguration;
            return this;
        }

        /**
         * Sets the value of {@link CfnProfilingGroupProps#getComputePlatform}
         * @param computePlatform `AWS::CodeGuruProfiler::ProfilingGroup.ComputePlatform`.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder computePlatform(java.lang.String computePlatform) {
            this.computePlatform = computePlatform;
            return this;
        }

        /**
         * Sets the value of {@link CfnProfilingGroupProps#getTags}
         * @param tags `AWS::CodeGuruProfiler::ProfilingGroup.Tags`.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        @SuppressWarnings("unchecked")
        public Builder tags(java.util.List<? extends software.amazon.awscdk.core.CfnTag> tags) {
            this.tags = (java.util.List<software.amazon.awscdk.core.CfnTag>)tags;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link CfnProfilingGroupProps}
         * @throws NullPointerException if any required attribute was not provided
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        @Override
        public CfnProfilingGroupProps build() {
            return new Jsii$Proxy(profilingGroupName, agentPermissions, anomalyDetectionNotificationConfiguration, computePlatform, tags);
        }
    }

    /**
     * An implementation for {@link CfnProfilingGroupProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements CfnProfilingGroupProps {
        private final java.lang.String profilingGroupName;
        private final java.lang.Object agentPermissions;
        private final java.lang.Object anomalyDetectionNotificationConfiguration;
        private final java.lang.String computePlatform;
        private final java.util.List<software.amazon.awscdk.core.CfnTag> tags;

        /**
         * Constructor that initializes the object based on values retrieved from the JsiiObject.
         * @param objRef Reference to the JSII managed object.
         */
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(objRef);
            this.profilingGroupName = this.jsiiGet("profilingGroupName", java.lang.String.class);
            this.agentPermissions = this.jsiiGet("agentPermissions", java.lang.Object.class);
            this.anomalyDetectionNotificationConfiguration = this.jsiiGet("anomalyDetectionNotificationConfiguration", java.lang.Object.class);
            this.computePlatform = this.jsiiGet("computePlatform", java.lang.String.class);
            this.tags = this.jsiiGet("tags", software.amazon.jsii.NativeType.listOf(software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.core.CfnTag.class)));
        }

        /**
         * Constructor that initializes the object based on literal property values passed by the {@link Builder}.
         */
        @SuppressWarnings("unchecked")
        private Jsii$Proxy(final java.lang.String profilingGroupName, final java.lang.Object agentPermissions, final java.lang.Object anomalyDetectionNotificationConfiguration, final java.lang.String computePlatform, final java.util.List<? extends software.amazon.awscdk.core.CfnTag> tags) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.profilingGroupName = java.util.Objects.requireNonNull(profilingGroupName, "profilingGroupName is required");
            this.agentPermissions = agentPermissions;
            this.anomalyDetectionNotificationConfiguration = anomalyDetectionNotificationConfiguration;
            this.computePlatform = computePlatform;
            this.tags = (java.util.List<software.amazon.awscdk.core.CfnTag>)tags;
        }

        @Override
        public java.lang.String getProfilingGroupName() {
            return this.profilingGroupName;
        }

        @Override
        public java.lang.Object getAgentPermissions() {
            return this.agentPermissions;
        }

        @Override
        public java.lang.Object getAnomalyDetectionNotificationConfiguration() {
            return this.anomalyDetectionNotificationConfiguration;
        }

        @Override
        public java.lang.String getComputePlatform() {
            return this.computePlatform;
        }

        @Override
        public java.util.List<software.amazon.awscdk.core.CfnTag> getTags() {
            return this.tags;
        }

        @Override
        public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
            final com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
            final com.fasterxml.jackson.databind.node.ObjectNode data = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();

            data.set("profilingGroupName", om.valueToTree(this.getProfilingGroupName()));
            if (this.getAgentPermissions() != null) {
                data.set("agentPermissions", om.valueToTree(this.getAgentPermissions()));
            }
            if (this.getAnomalyDetectionNotificationConfiguration() != null) {
                data.set("anomalyDetectionNotificationConfiguration", om.valueToTree(this.getAnomalyDetectionNotificationConfiguration()));
            }
            if (this.getComputePlatform() != null) {
                data.set("computePlatform", om.valueToTree(this.getComputePlatform()));
            }
            if (this.getTags() != null) {
                data.set("tags", om.valueToTree(this.getTags()));
            }

            final com.fasterxml.jackson.databind.node.ObjectNode struct = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            struct.set("fqn", om.valueToTree("@aws-cdk/aws-codeguruprofiler.CfnProfilingGroupProps"));
            struct.set("data", data);

            final com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            obj.set("$jsii.struct", struct);

            return obj;
        }

        @Override
        public boolean equals(Object o) {
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;

            CfnProfilingGroupProps.Jsii$Proxy that = (CfnProfilingGroupProps.Jsii$Proxy) o;

            if (!profilingGroupName.equals(that.profilingGroupName)) return false;
            if (this.agentPermissions != null ? !this.agentPermissions.equals(that.agentPermissions) : that.agentPermissions != null) return false;
            if (this.anomalyDetectionNotificationConfiguration != null ? !this.anomalyDetectionNotificationConfiguration.equals(that.anomalyDetectionNotificationConfiguration) : that.anomalyDetectionNotificationConfiguration != null) return false;
            if (this.computePlatform != null ? !this.computePlatform.equals(that.computePlatform) : that.computePlatform != null) return false;
            return this.tags != null ? this.tags.equals(that.tags) : that.tags == null;
        }

        @Override
        public int hashCode() {
            int result = this.profilingGroupName.hashCode();
            result = 31 * result + (this.agentPermissions != null ? this.agentPermissions.hashCode() : 0);
            result = 31 * result + (this.anomalyDetectionNotificationConfiguration != null ? this.anomalyDetectionNotificationConfiguration.hashCode() : 0);
            result = 31 * result + (this.computePlatform != null ? this.computePlatform.hashCode() : 0);
            result = 31 * result + (this.tags != null ? this.tags.hashCode() : 0);
            return result;
        }
    }
}
